@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.1100';
+our $VERSION = '0.1101';
 
 use v5.36;
 
@@ -331,7 +331,7 @@ sub flicker ($self, $device, $dt, $event) {
 
     $self->running(1);
 
-    my $value = 0;
+    my $value = $self->range_bottom;
 
     $self->rtc->loop->add(
         IO::Async::Timer::Countdown->new(
@@ -346,7 +346,7 @@ sub flicker ($self, $device, $dt, $event) {
                 else {
                     my $cc = [ 'control_change', $self->channel, $self->control, $value ];
                     $self->rtc->send_it($cc);
-                    $value = $value ? 0 : 127;
+                    $value = $value == $self->range_top ? $self->range_bottom : $self->range_top;
                     $c->start;
                 }
             },
@@ -370,7 +370,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.1100
+version 0.1101
 
 =head1 SYNOPSIS
 
